new_segment_id

Function new_segment_id 

pub fn new_segment_id(counter: u64) -> String
An id for a new segment, from the process, a counter and the clock — unique within an index without needing to look at what is already there.