Module cursor

Module cursor 

Cursors: forward-only readers over a sorted posting list.

Structs

SliceCursor
Cursor over a slice of Postings sorted by id.

Traits

PostingCursor
A forward-only reader over one posting list, sorted by record id.