SliceCursor

Struct SliceCursor 

pub struct SliceCursor<'a> { /* private fields */ }
Cursor over a slice of Postings sorted by id.

Implementations

Source

impl<'a> SliceCursor<'a>

pub fn new(items: &'a [Posting]) -> Self

Cursor at the start of items. The slice must be sorted by id with no duplicates and satisfy the ceiling invariant.

pub fn position(&self) -> usize

Index of the current element within the slice.